@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 from copy import copy
+from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.state import DATAFRAME_SOURCE_DUPLICATED, State
@@ -28,10 +28,6 @@ class DataframeDuplicateStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Duplicated a Dataframe'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'dataframe_duplicate_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -44,16 +40,20 @@ class DataframeDuplicateStepPerformer(StepPerformer):
         sheet_index: int,
         **params
     ) -> Tuple[State, Optional[Dict[str, Any]]]:
-        post_state = copy(prev_state)
+        post_state = prev_state.copy()
 
         # Execute the step
+        pandas_start_time = perf_counter()
         df_copy = post_state.dfs[sheet_index].copy(deep=True)
+        pandas_processing_time = perf_counter() - pandas_start_time
         new_name = get_first_unused_dataframe_name(post_state.df_names, post_state.df_names[sheet_index] + '_copy')
         # Copy the formatting to the new sheet
         format_types = post_state.column_format_types[sheet_index].copy()
         post_state.add_df_to_state(df_copy, DATAFRAME_SOURCE_DUPLICATED, df_name=new_name, format_types=format_types)
 
-        return post_state, None
+        return post_state, {
+            'pandas_processing_time': pandas_processing_time
+        }
 
     @classmethod
     def transpile( # type: ignore
